#!
# -*- coding: utf_8 -*-
"""
Extension pour faciliter l'édition MoinMoin.
Gestion de la fenêtre des options.

Copyright : Agence universitaire de la Francophonie
Licence : GNU General Public Licence, version 2
Auteur : Jean Christophe André
Date de création : juillet 2009
"""
import uno
import unohelper

# interfaces
from com.sun.star.lang import XServiceInfo
from com.sun.star.awt import XContainerWindowEventHandler

# main class
class DialogHandler(unohelper.Base, XServiceInfo, XContainerWindowEventHandler):
    def __init__(self, ctx):
        self.ctx = ctx;
        self.cp = self.ctx.ServiceManager.createInstanceWithContext(
            "com.sun.star.configuration.ConfigurationProvider", self.ctx)
        # options MoinMoin
        node = uno.createUnoStruct("com.sun.star.beans.PropertyValue")
        node.Name = "nodepath"
        node.Value = "/org.libreoffice.moinmoin/General"
        self.node = node
        self.cfg_names = ("MoinMoinOldStyle", "MoinMoinVertOnMulti", )
        return

    # XServiceInfo
    def supportsService(self, name):
        return False

    # XServiceInfo
    def getImplementationName(self):
        return "org.libreoffice.moinmoin.DialogHandler"

    # XServiceInfo
    def getSupportedServiceNames(self):
        return ()

    # XContainerWindowEventHandler
    def getSupportedMethodNames(self):
        return ("external_event",)

    # XContainerWindowEventHandler
    def callHandlerMethod(self, window, eventObject, method):
        if method == "external_event":
            try:
                self.handleExternalEvent(window, eventObject)
            except:
                pass
        return True

    def handleExternalEvent(self, window, eventName):
        if eventName == "ok":
            self.saveData(window)
        elif eventName == "back":
            self.loadData(window, "back")
        elif eventName == "initialize":
            self.loadData(window, "initialize")
        return True

    # load and set the data
    def loadData(self, window, ev):
        name = window.getModel().Name
        if name != "MacrosDialog":
            return
        settings = self.configreader()
        if not settings:
            return
        # options MoinMoin
        for name in self.cfg_names:
            window.getControl(name).setState(int(settings.get(name, True)))
        return

    # making the save data
    def saveData(self,window):
        name = window.getModel().Name
        if name != "MacrosDialog":
            return
        settings = {}
        # options MoinMoin
        for name in self.cfg_names:
            settings[name] = bool(window.getControl(name).State)
        self.configwriter(settings)
        return

    # read configuration
    def configreader(self):
        settings = {}
        # options MoinMoin
        try:
            ConfigReader = self.cp.createInstanceWithArguments(
                "com.sun.star.configuration.ConfigurationAccess",
                (self.node,))
            for name in self.cfg_names:
                settings[name] = ConfigReader.getByName(name)
        except:
            pass
        return settings

    # write configuration
    def configwriter(self, settings):
        # options MoinMoin
        try:
            ConfigWriter = self.cp.createInstanceWithArguments(
                "com.sun.star.configuration.ConfigurationUpdateAccess",
                (self.node,))
            for name in self.cfg_names:
                ConfigWriter.replaceByName(name, settings[name])
            ConfigWriter.commitChanges()
        except:
            pass

# uno implementation
g_ImplementationHelper = unohelper.ImplementationHelper()
g_ImplementationHelper.addImplementation( \
    DialogHandler, "org.libreoffice.moinmoin.DialogHandler", \
    ("org.libreoffice.moinmoin.DialogHandler",),)
